% Generated by tinyroxygen: do not edit by hand
% Please edit documentation in tinyroxygen-package.R
\name{roxygenise}
\alias{roxygenise}
\alias{roxygenize}
\title{Generate documentation from roxygen comments}
\usage{
roxygenise(pkgdir = NULL)
}

\arguments{
\item{pkgdir}{Path to the package directory. Defaults to \code{NULL}.}
}

\value{
Invisibly returns the package directory.
}

\description{
Parses the '#'' comment blocks in the 'R/' directory of a
  package, writes the corresponding '.Rd' files to 'man/', and writes a
  'NAMESPACE' file based on '@export' and related tags.
}

\examples{
\dontrun{
roxygenise("path/to/package")
}
}

