% Generated by tinyroxygen: do not edit by hand
% Please edit documentation in tinyroxygen-package.R
\name{tinyroxygen-package}
\alias{tinyroxygen-package}
\title{tinyroxygen: a tiny 'roxygen'-style documentation generator}
\description{
Reads '#'' comment blocks above R functions and objects and
  turns them into '.Rd' documentation files and a 'NAMESPACE' file, using
  base R only. It is a minimal, non-magical alternative to 'roxygen2' for
  situations where installing 'roxygen2' and its dependencies is
  impractical (e.g. slow or restricted institutional servers).
}

\keyword{internal}
